import 'dart:convert';

import 'package:crypton/crypton.dart';

class RsaProxy {
  String get privateKey => _rsaPrivateKey.toString();
  String get publicKey => _rsaPublicKey.toString();

  RSAPrivateKey _rsaPrivateKey;
  RSAPublicKey _rsaPublicKey;

  RsaProxy(privateKeyString, publicKeyString) {
    if (privateKeyString != null) {
      _rsaPrivateKey = RSAPrivateKey.fromString(privateKeyString);
    }
    if (publicKeyString != null) {
      _rsaPublicKey = RSAPublicKey.fromString(publicKeyString);
    }
  }

  bool verifySignature(String message, String signedText) {
    try {
      bool verified = _rsaPublicKey.verifySignature(message, signedText);
      return verified;
    } catch (e) {
      print('rsa verifySignature error : $e');
    }
    return false;
  }

  String sign(String message) {
    try {
      String signature = _rsaPrivateKey.createSignature(message);
      return signature;
    } catch (e) {
      print('rsa sign error : $e');
    }
    return null;
  }

  static RsaProxy create() {
    RSAKeypair rsaKeypair = RSAKeypair.fromRandom();
    RsaProxy rsa = RsaProxy(null, null);
    rsa._rsaPublicKey = rsaKeypair.publicKey;
    rsa._rsaPrivateKey = rsaKeypair.privateKey;
    return rsa;
  }
}
